part of 'auth_bloc.dart';

@immutable
abstract class AuthState extends Equatable {
  const AuthState();
  @override
  List<Object?> get props => [];
}

class AuthInitial extends AuthState {}

class AuthLoading extends AuthState {}

class AuthCodeSentSuccess extends AuthState {
  final String phone;
  final String countryCode;

  const AuthCodeSentSuccess({required this.phone, required this.countryCode});

  @override
  List<Object?> get props => [phone, countryCode];
}

class AuthNeedsInfo extends AuthState {}

class AuthSuccess extends AuthState {}

class AuthFailure extends AuthState {
  final String message;
  const AuthFailure(this.message);

  @override
  List<Object?> get props => [message];
}